@@ -325,7 +325,7 @@ class MultiTileMergeHelper:
             outputs_path.append(Path(tmp))
 
         if band_descriptions:
-            for old_key, new_key in zip(valid_tiles.keys(), band_descriptions):
+            for old_key, new_key in zip(list(valid_tiles.keys()), band_descriptions):
                 valid_tiles[new_key] = valid_tiles.pop(old_key)
 
         create_multiband_tif(
